pub struct Client {
inner: Arc<Inner>,
}Fields
inner: Arc<Inner>Implementations
Sourceimpl Client
impl Client
Sourcepub fn new() -> Self
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
pub fn new() -> Self
shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
Creates a client whose query and control lanes intentionally share the default manager.
Sourcepub fn with_urls<U, A>(urls: A) -> Self
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
pub fn with_urls<U, A>(urls: A) -> Self
shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
Creates a client whose query and control lanes intentionally share one manager.
Sourcepub fn with_urls_and_options<U, A>(urls: A, options: ClientOptions) -> Self
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers instead
pub fn with_urls_and_options<U, A>(urls: A, options: ClientOptions) -> Self
shares one manager between query and control lanes; use with_query_and_control_managers instead
Creates a client with URLs and custom options.
The query and control lanes intentionally share one manager.
Sourcepub fn with_tls_and_urls<U, A>(
urls: A,
client_tls: ClientTlsOption,
) -> Result<Self>
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers instead
pub fn with_tls_and_urls<U, A>( urls: A, client_tls: ClientTlsOption, ) -> Result<Self>
shares one manager between query and control lanes; use with_query_and_control_managers instead
Creates a TLS client whose query and control lanes intentionally share one manager.
Sourcepub fn with_tls_and_urls_and_options<U, A>(
urls: A,
client_tls: ClientTlsOption,
options: ClientOptions,
) -> Result<Self>
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers instead
pub fn with_tls_and_urls_and_options<U, A>( urls: A, client_tls: ClientTlsOption, options: ClientOptions, ) -> Result<Self>
shares one manager between query and control lanes; use with_query_and_control_managers instead
Creates a client with TLS URLs and custom options.
The query and control lanes intentionally share one manager.
Sourcepub fn with_manager_and_urls<U, A>(
channel_manager: ChannelManager,
urls: A,
) -> Self
👎Deprecated: shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
pub fn with_manager_and_urls<U, A>( channel_manager: ChannelManager, urls: A, ) -> Self
shares one manager between query and control lanes; use with_query_and_control_managers with independently constructed managers instead
Creates a client with one manager shared intentionally by query and control lanes.
Sourcepub fn with_query_and_control_managers<U, A>(
query_channel_manager: ChannelManager,
control_channel_manager: ChannelManager,
urls: A,
) -> Self
pub fn with_query_and_control_managers<U, A>( query_channel_manager: ChannelManager, control_channel_manager: ChannelManager, urls: A, ) -> Self
Creates a client with query and control lanes backed by the supplied managers.
The lanes are isolated only when the supplied managers are independently constructed; this constructor does not enforce that they are distinct.
fn with_query_and_control_managers_and_options<U, A>( query_channel_manager: ChannelManager, control_channel_manager: ChannelManager, urls: A, options: ClientOptions, ) -> Self
Sourcepub fn with_manager_and_urls_and_options<U, A>(
channel_manager: ChannelManager,
urls: A,
options: ClientOptions,
) -> Self
👎Deprecated: shares this manager and its pool between query and control lanes; use with_query_and_control_managers instead
pub fn with_manager_and_urls_and_options<U, A>( channel_manager: ChannelManager, urls: A, options: ClientOptions, ) -> Self
shares this manager and its pool between query and control lanes; use with_query_and_control_managers instead
Creates a client with a channel manager, URLs, and custom options.
The query and control lanes intentionally share this manager and its pool.
pub fn start<U, A>(&self, urls: A)
fn trigger_health_check(&self)
pub fn find_channel(&self) -> Result<(String, Channel)>
pub fn max_grpc_recv_message_size(&self) -> usize
pub fn max_grpc_send_message_size(&self) -> usize
Sourcepub fn make_flight_client(
&self,
send_compression: bool,
accept_compression: bool,
) -> Result<FlightClient>
pub fn make_flight_client( &self, send_compression: bool, accept_compression: bool, ) -> Result<FlightClient>
Creates a Flight client on the query lane for DoGet/distributed reads.
This public name is retained for compatibility.
pub(crate) fn make_control_flight_client( &self, send_compression: bool, accept_compression: bool, ) -> Result<FlightClient>
fn make_flight_client_with_manager( &self, channel_manager: &ChannelManager, send_compression: bool, accept_compression: bool, ) -> Result<FlightClient>
pub(crate) fn raw_region_client( &self, ) -> Result<(String, PbRegionClient<Channel>)>
pub(crate) fn raw_flow_client(&self) -> Result<(String, PbFlowClient<Channel>)>
pub fn make_prometheus_gateway_client( &self, ) -> Result<PrometheusGatewayClient<Channel>>
pub async fn health_check(&self) -> Result<()>
Sourcepub fn channel_pool_sizes(&self) -> (usize, usize)
pub fn channel_pool_sizes(&self) -> (usize, usize)
Returns the number of cached channels in the query and control pools for tests.